summaryrefslogtreecommitdiff
path: root/sd/source/ui/slidesorter/cache/SlsBitmapCache.hxx
diff options
context:
space:
mode:
Diffstat (limited to 'sd/source/ui/slidesorter/cache/SlsBitmapCache.hxx')
-rw-r--r--sd/source/ui/slidesorter/cache/SlsBitmapCache.hxx16
1 files changed, 8 insertions, 8 deletions
diff --git a/sd/source/ui/slidesorter/cache/SlsBitmapCache.hxx b/sd/source/ui/slidesorter/cache/SlsBitmapCache.hxx
index 734c630d31ce..34799b08d0a2 100644
--- a/sd/source/ui/slidesorter/cache/SlsBitmapCache.hxx
+++ b/sd/source/ui/slidesorter/cache/SlsBitmapCache.hxx
@@ -85,7 +85,7 @@ public:
*/
void Clear (void);
/** Return <TRUE/> when the cache is full, i.e. the cache compactor had
to be run.
*/
bool IsFull (void) const;
@@ -95,11 +95,11 @@ public:
*/
sal_Int32 GetSize (void);
/** Return <TRUE/> when a preview bitmap exists for the given key.
*/
bool HasBitmap (const CacheKey& rKey);
/** Return <TRUE/> when a preview bitmap exists for the given key and
when it is up-to-date.
*/
bool BitmapIsUpToDate (const CacheKey& rKey);
@@ -121,7 +121,7 @@ public:
anymore.
@return
When the key references a page in the cache then
- return <TRUE/>. When the key is not known then <FALSE/>
+ return <sal_True/>. When the key is not known then <sal_False/>
is returned.
*/
bool InvalidateBitmap (const CacheKey& rKey);
@@ -162,12 +162,12 @@ public:
part of) the cache. The entries of the index are sorted according
to last access times with the least recently access time first.
@param bIncludePrecious
- When this flag is <TRUE/> entries with the precious flag set are
- included in the index. When the flag is <FALSE/> these entries
+ When this flag is <sal_True/> entries with the precious flag set are
+ included in the index. When the flag is <sal_False/> these entries
are ommited.
@param bIncludeNoPreview
- When this flag is <TRUE/> entries with that have no preview
- bitmaps are included in the index. When the flag is <FALSE/> these entries
+ When this flag is <sal_True/> entries with that have no preview
+ bitmaps are included in the index. When the flag is <sal_False/> these entries
are ommited.
*/
::std::auto_ptr<CacheIndex> GetCacheIndex (
@@ -85,7 +85,7 @@ public:
*/
void Clear (void);
- /** Return <TRUE/> when the cache is full, i.e. the cache compactor had
+ /** Return <sal_True/> when the cache is full, i.e. the cache compactor had
to be run.
*/
@@ -95,11 +95,11 @@ public:
*/
sal_Int32 GetSize (void);
- /** Return <TRUE/> when a preview bitmap exists for the given key.
+ /** Return <sal_True/> when a preview bitmap exists for the given key.
*/
bool HasBitmap (const CacheKey& rKey);
@@ -95,11 +95,11 @@ public:
*/
bool HasBitmap (const CacheKey& rKey);
- /** Return <TRUE/> when a preview bitmap exists for the given key and
+ /** Return <sal_True/> when a preview bitmap exists for the given key and
when it is up-to-date.
*/